@@ -26,7 +26,7 @@
 #  OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 #  SUCH DAMAGE.
 
-# $XFree86: doctools/sgmlformat/sgmlfmt/sgmlfmt.pl,v 1.16 2000/06/14 01:50:53 dawes Exp $
+# $XFree86: doctools/sgmlformat/sgmlfmt/sgmlfmt.pl,v 1.19 2003/10/19 19:37:32 dawes Exp $
 
 # Format an sgml document tagged according to the linuxdoc DTD.
 # by John Fieber <jfieber@freebsd.org> for the FreeBSD documentation
@@ -158,6 +158,10 @@ sub gen_roff {
 # Generate something from roff output
 #
 
+# Extra groff options required on some systems
+
+$groff_opts = "";
+
 sub do_groff {
     local($driver, $postproc, $preamble) = @_;
     @cleanfiles = (@cleanfiles, "${fileroot}.trf", "${fileroot}.tmp", 
@@ -172,7 +176,8 @@ sub do_groff {
     close(outfile);
     &exitiferror($?);
     
-    open(infile, "groff -T ${driver} -t -M ${sgmldir}/tmac " .
+    open(infile, "env GROFF_NO_SGR=1 groff ${groff_opts} -T ${driver} " .
+	   "-t -M ${sgmldir}/tmac " .
 	   "${fileroot}.trf ${postproc} |");
     open(outfile, "> ${fileroot}.${driver}");
     if ("$opt_n") {
@@ -193,7 +198,8 @@ sub do_groff {
     # in the file and we need a second pass to resolve them correctly.
 
     if (stat("${fileroot}.tmp")) {
-	open(infile, "groff -T ${driver} -t -M ${sgmldir}/tmac " .
+	open(infile, "env GROFF_NO_SGR=1 groff ${groff_opts} -T ${driver} " .
+		"-t -M ${sgmldir}/tmac " .
 		"${fileroot}.trf ${postproc} |");
 	open(outfile, "> ${fileroot}.${driver}");
 	while (<infile>) {
@@ -778,6 +784,13 @@ sub main {
     } else {
 	$nroff_preamble = ".nr NOPBRK 0\n";
     }
+
+    # See if groff has the -U flag.  We need to use it when it is present.
+
+    if (system("groff -U /dev/null > /dev/null 2>&1") == 0) {
+	$groff_opts = "-U";
+    }
+
     # Generate the output
     if ($opt_f eq 'html') {
     	# Set the character encoding
